<?php

require_once DOL_DOCUMENT_ROOT . '/core/class/html.form.class.php';

/**
 * ActionsUserSwitcher class
 */

class ActionsUserSwitcher
{
	/**
	 * Overloading the printSearchForm function
	 *
	 * @param   array()         $parameters     Hook metadatas (context, etc...)
	 * @param   CommonObject    &$object        The object to process (an invoice if you are in invoice module, a propale in propale's module, etc...)
	 * @param   string          &$action        Current action (if set). Generally create or edit or null
	 * @param   HookManager     $hookmanager    Hook manager propagated to allow calling another hook
	 * @return  int                             < 0 on error, 0 on success, 1 to replace standard code
	 */
	public function printSearchForm($parameters, &$object, &$action, $hookmanager)
	{
		global $conf, $user;

		$error = 0; // Error counter

		if (! empty($conf->dropdownmenu->enabled)) { // if dropdown menu module is enabled (exit function)
			return 0;
		}

		if (in_array('leftblock', explode(':', $parameters['context'])) && ($user->rights->userswitcher->use || (isset($_SESSION['dol_main_login']) && ! empty($_SESSION['dol_main_login']))))
		{
			$this->resprints = $this->getUsersListHTML();
		}

		if (! $error)
		{
			return 0; // or return 1 to replace standard code
		}
		else
		{
			return -1;
		}
	}

	/**
	 * Overloading the printTopRightMenu function
	 *
	 * @param   array()         $parameters     Hook metadatas (context, etc...)
	 * @param   CommonObject    &$object        The object to process (an invoice if you are in invoice module, a propale in propale's module, etc...)
	 * @param   string          &$action        Current action (if set). Generally create or edit or null
	 * @param   HookManager     $hookmanager    Hook manager propagated to allow calling another hook
	 * @return  int                             < 0 on error, 0 on success, 1 to replace standard code
	 */
	public function printTopRightMenu($parameters, &$object, &$action, $hookmanager)
	{
		global $conf, $user, $langs;

		$error = 0; // Error counter

		if (in_array('toprightmenu', explode(':', $parameters['context'])) && ! empty($conf->dropdownmenu->enabled) && ($user->rights->userswitcher->use || (isset($_SESSION['dol_main_login']) && ! empty($_SESSION['dol_main_login']))))
		{
			// UserSwitcher shortcut
			$langs->load('userswitcher@userswitcher');
			$text = '<a href="#" id="userswitcher-button">';
			$dolibarr_version = explode('.', DOL_VERSION);
			if ((int)$dolibarr_version[0] >= 6) {
				$text.= '<span class="fa fa-user atoplogin"></span>';
			}
			else {
				$text.= img_picto($langs->trans("UserSwitcher"), 'object_userswitcher.png@userswitcher');
			}
			$text.= '</a>';
			$this->resprints = @Form::textwithtooltip('',$langs->trans("UserSwitcher"),2,1,$text,'login_block_elem',2);
		}

		if (! $error)
		{
			return 0; // or return 1 to replace standard code
		}
		else
		{
			$this->errors[] = 'Could not add userswitcher shortcut to the top right menu';
			return -1;
		}
	}

	/**
	 * Overloading the printCommonFooter function
	 *
	 * @param   array()         $parameters     Hook metadatas (context, etc...)
	 * @param   CommonObject    &$object        The object to process (an invoice if you are in invoice module, a propale in propale's module, etc...)
	 * @param   string          &$action        Current action (if set). Generally create or edit or null
	 * @param   HookManager     $hookmanager    Hook manager propagated to allow calling another hook
	 * @return  int                             < 0 on error, 0 on success, 1 to replace standard code
	 */
	public function printCommonFooter($parameters, &$obj, &$action, $hookmanager)
	{
		global $langs, $user, $conf;

		$error = 0; // Error counter
		$context = explode(':', $parameters['context']);

		if ((in_array('main', $context) || in_array('login', $context)) && ! empty($conf->dropdownmenu->enabled) && ($user->rights->userswitcher->use || (isset($_SESSION['dol_main_login']) && ! empty($_SESSION['dol_main_login']))))
		{
			$langs->load('userswitcher@userswitcher');
			echo '<div id="userswitcher-dialog" title="'.$langs->trans('UserSwitcher').'" style="display: none;">';
			echo $this->getUsersListHTML('100%');
			echo '</div>';

			echo '<script type="text/javascript">
			$(document).ready(function () {
				$("#userswitcher-button").click(function(e){
					$("#userswitcher-dialog").show().dialog({
						width: 400,
						resizable: false,
						modal: true,
						buttons: {
							"'.$langs->transnoentities('CloseDialog').'": function() {
								$("#userswitcher-dialog").dialog("close");
							}
						}
					});
					e.preventDefault();
				});
			});
			</script>' . "\n";
		}

		if (! $error)
		{
			return 0; // or return 1 to replace standard code
		}
		else
		{
			$this->errors[] = 'Could not render userswitcher dialog';
			return -1;
		}
	}

	/**
	 * Return users list html
	 * 
	 * @return string users list html
	 */
	private function getUsersListHTML($width = '200px')
	{
		global $user, $conf, $db, $langs;

		// Get users
		$main_login = isset($_SESSION['dol_main_login']) ? $_SESSION['dol_main_login'] : $user->login;
		$fullNameMode = 0; //Lastname + firstname
		$query = 'SELECT rowid, lastname, firstname, login, photo FROM '.MAIN_DB_PREFIX.'user WHERE statut = 1 AND entity IN(0, '.$conf->entity.')';
		if (! empty($conf->global->USER_SWITCHER_HIDDEN_USERS))
		{
			$hidden_users = explode(',', $conf->global->USER_SWITCHER_HIDDEN_USERS);
			foreach ($hidden_users as $key => $login) {
				if ($login == $main_login) {
					unset($hidden_users[$key]);
				}
			}
			$query.= " AND login NOT IN ('".join("','", $hidden_users)."')";
		}
		if(empty($conf->global->MAIN_FIRSTNAME_NAME_POSITION)) {
			$query.= " ORDER BY firstname ASC";
			$fullNameMode = 1; //firstname + lastname
		} else {
			$query.= " ORDER BY lastname ASC";
		}

		$result = $db->query($query);
		$users = array();
		$userstatic = new User($db);

		if ($result)
		{
			$rows_count = $db->num_rows($result);
			$row_num = 0;

			while($row_num < $rows_count) {
				$obj = $db->fetch_object($result);
				$userstatic->id = $obj->rowid;
				$userstatic->lastname = $obj->lastname;
				$userstatic->firstname = $obj->firstname;
				$userstatic->photo = $obj->photo;
				if (! empty($obj->photo)) {
					$picto = Form::showphoto('userphoto', $userstatic, 0, 0, 0, 'userphoto', 'mini', 0, 1);
				}
				else {
					$picto = img_object('', 'user', '', 0, 0, 0);
				}
				$fullname = $userstatic->getFullName($langs, $fullNameMode);
				$users[$obj->login] = array(
					'image'    => $picto,
					'fullname' => $fullname
				);
				$row_num++;
			}
		}

		// Show users
		$form = new Form($db);
		$html = '<div style="margin-top: 12px;">';
		//$html.= $form->select_dolusers($user->id, 'currentuserid', 0, null, 0, '', '', 0, 0, 0, 'AND statut = 1');
		$html.= '<select id="currentuserid" style="width: '.$width.'">';
		foreach ($users as $key => $value) {
			$html.= '<option value="'.$key.'" data-image="'.htmlentities($value['image']).'"'.($key == $_SESSION['dol_login'] ? ' selected' : '').'>'.$value['fullname'].'</option>';
		}
		$html.= '</select>';
		$html.= '<script type="text/javascript">
		$(document).ready(function () {
			$("#currentuserid").select2({
				dir: "ltr",
				width: "resolve", /* off or resolve */
				minimumInputLength: 0,
				templateResult: addUserPic,
				templateSelection: addUserPic
			});
			function addUserPic(option) {
				if (!option.id) {
					return option.text;
				}
				var optionimage = $(option.element).data("image"); 
				if(!optionimage){
					return option.text;
				} else {
					var $opt = $("<span>" + optionimage + " " + $(option.element).text() + "</span>");
					return $opt;
				}
			};
			$("#currentuserid").change(function() {
				$(location).attr("href", "'.dol_buildpath('userswitcher/set_user.php', 1).'?backtopage='.urlencode($_SERVER['PHP_SELF'].'?'.$_SERVER['QUERY_STRING']).'&login=" + $(this).val());
			});
		});
		</script>' . "\n";
		$html.= '</div>';

		return $html;
	}
}
