<?php
/* Copyright (C) 2001-2005 Rodolphe Quiedeville <rodolphe@quiedeville.org>
 * Copyright (C) 2004-2015 Laurent Destailleur  <eldy@users.sourceforge.net>
 * Copyright (C) 2005-2012 Regis Houssin        <regis.houssin@inodbox.com>
 * Copyright (C) 2015      Jean-François Ferry	<jfefe@aternatik.fr>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 */

/**
 *	\file       ichosting/ichostingindex.php
 *	\ingroup    ichosting
 *	\brief      Home page of ichosting top menu
 */

// Load Dolibarr environment
$res = 0;
// Try main.inc.php into web root known defined into CONTEXT_DOCUMENT_ROOT (not always defined)
if (!$res && !empty($_SERVER["CONTEXT_DOCUMENT_ROOT"])) {
	$res = @include $_SERVER["CONTEXT_DOCUMENT_ROOT"]."/main.inc.php";
}
// Try main.inc.php into web root detected using web root calculated from SCRIPT_FILENAME
$tmp = empty($_SERVER['SCRIPT_FILENAME']) ? '' : $_SERVER['SCRIPT_FILENAME']; $tmp2 = realpath(__FILE__); $i = strlen($tmp) - 1; $j = strlen($tmp2) - 1;
while ($i > 0 && $j > 0 && isset($tmp[$i]) && isset($tmp2[$j]) && $tmp[$i] == $tmp2[$j]) {
	$i--; $j--;
}
if (!$res && $i > 0 && file_exists(substr($tmp, 0, ($i + 1))."/main.inc.php")) {
	$res = @include substr($tmp, 0, ($i + 1))."/main.inc.php";
}
if (!$res && $i > 0 && file_exists(dirname(substr($tmp, 0, ($i + 1)))."/main.inc.php")) {
	$res = @include dirname(substr($tmp, 0, ($i + 1)))."/main.inc.php";
}
// Try main.inc.php using relative path
if (!$res && file_exists("../main.inc.php")) {
	$res = @include "../main.inc.php";
}
if (!$res && file_exists("../../main.inc.php")) {
	$res = @include "../../main.inc.php";
}
if (!$res && file_exists("../../../main.inc.php")) {
	$res = @include "../../../main.inc.php";
}
if (!$res) {
	die("Include of main fails");
}

require_once DOL_DOCUMENT_ROOT.'/core/class/html.formfile.class.php';
require_once DOL_DOCUMENT_ROOT . '/core/class/CMailFile.class.php';
require_once DOL_DOCUMENT_ROOT .'/core/class/html.formmail.class.php';
include DOL_DOCUMENT_ROOT.'/core/actions_sendmails.inc.php';
// Load translation files required by the page
$langs->loadLangs(array("ichosting@ichosting"));

$action = GETPOST('action', 'aZ09');


// Security check
// if (! $user->rights->ichosting->myobject->read) {
// 	accessforbidden();
// }
$socid = GETPOST('socid', 'int');
if (isset($user->socid) && $user->socid > 0) {
	$action = '';
	$socid = $user->socid;
}

$max = 5;
$now = dol_now();


/*
 * Actions
 */

// None


/*
 * View
 */

$form = new Form($db);
//$formfile = new FormFile($db);

llxHeader("", $langs->trans("SupportInovea"));


if(!empty($conf->global->ICHOSTING_INFO_CONTENT)) {
    print load_fiche_titre($langs->trans("ficheTitleSupportInfos"), '', '');
//HTML ICI
    print htmlspecialchars_decode($conf->global->ICHOSTING_INFO_CONTENT);
}
// Informations

//HTML
print load_fiche_titre($langs->trans("ficheTitleCreateTicket"), '', '');



$typeOfTicket = array(
    array("code" => "COM", "label" => "Question commerciale"),
    array("code" => "HELP", "label" => "Demande d'aide fonctionnelle"),
    array("code" => "ISSUE", "label" => "Problème ou Bug"),
    array("code" => "REQUEST", "label" => "Demande de changement ou d'amélioration"),
    array("code" => "PROJECT", "label" => "Projet"),
    array("code" => "OTHER", "label" => "Autre")
);

$typeOfSeverity = array(
    array("code" => "LOW", "label" => 'Faible'),
    array("code" => "NORMAL", "label" => 'Normal'),
    array("code" => "HIGH", "label" => 'Elevé'),
    array("code" => "BLOCKING", "label" => 'Critique')
);

$ticketParams = "";
//$ticketParams .=  '<table class="border" width="100%">';
//$ticketParams .=  '<tbody>';
$ticketParams .=  "<tr>";
$ticketParams .=  "<td class='titlefieldcreate'><span class='fieldrequired'>Type de demande</span></td>";
$ticketParams .=   "<td>";
$ticketParams .=  "<select class='flat' name='typeOfTicket'>";
for($i=0;$i<count($typeOfTicket);$i++){
    $ticketParams .=  "<option value='".$typeOfTicket[$i]["code"]."'>".$typeOfTicket[$i]["label"]."</option>";
}
$ticketParams .=  "</select>";
$ticketParams .=  "</td>";
$ticketParams .=  "</tr>";

$ticketParams .=  "<tr>";
$ticketParams .=  "<td class='titlefieldcreate'><span class='fieldrequired'>Sévérité</span></td>";
$ticketParams .=   "<td>";
$ticketParams .=  "<select class='flat' name='ticketSeverity'>";
for($i=0;$i<count($typeOfSeverity);$i++){
    $ticketParams .=  "<option value='".$typeOfSeverity[$i]["code"]."'>".$typeOfSeverity[$i]["label"]."</option>";
}
$ticketParams .=  "</select>";
$ticketParams .=  "</td>";
$ticketParams .=  "</tr>";

//$ticketParams .=  '</tbody>';
//$ticketParams .=  '</table>';


$formmail = new FormMail($db);
$formmail->withfile=2;
$formmail->withfrom=0;
$formmail->withto=0;
$formmail->withtocc=0;

if(GETPOSTISSET("sendmail")){

    if(GETPOST("typeOfTicket") != "" && GETPOST("ticketSeverity") != "" && GETPOST("subject") != "" && GETPOST("message") != ""){

        if(!empty($conf->global->ICHOSTING_DEFAULT_SUPPORT)){
            $sendTo = $conf->global->ICHOSTING_DEFAULT_SUPPORT;
        }
        else{
            $sendTo = "support@inovea-conseil.com";
        }
        $subject = '[Client][Type='.GETPOST("typeOfTicket").']';
        $subject .= '[Importance='.GETPOST("ticketSeverity").']';
        $subject .= '[Sujet='.GETPOST("subject").']';
        $infosMessage = "------------------------- \n";
        $infosMessage .= "Nom société : ".$conf->global->MAIN_INFO_SOCIETE_NOM."\n";
        $infosMessage .= "Utilisateur (nom) : ".$user->lastname."\n";
        $infosMessage .= "Utilisateur (prenom) : ".$user->firstname."\n";
        $infosMessage .= "Utilisateur (login) : ".$user->login."\n";
        $infosMessage .= "------------------------- \n";
        $infosMessage .= "Message : \n";
        $message = '[Message="'.$infosMessage. GETPOST("message", 'alpha').'"]';
        $from = '';
        if(!empty($user->email)){
            $from = $user->email;
        }
        if(empty($from) && !empty($conf->global->MAIN_INFO_SOCIETE_MAIL)){
            $from = $conf->global->MAIN_INFO_SOCIETE_MAIL;
        }
        if(empty($from) && !empty($conf->global->ICHOSTING_DEFAULT_SENDER)){
            $from = $conf->global->ICHOSTING_DEFAULT_SENDER;
        }
        if(empty($from) && !empty($conf->global->MAIN_MAIL_EMAIL_FROM)){
            $from = $conf->global->MAIN_MAIL_EMAIL_FROM;
        }
        if(empty($from) && !empty($conf->global->ITSENDERMAIL)){
            $from = $conf->global->ITSENDERMAIL;
        }
        if(empty($from) && !empty($conf->global->MAILING_EMAIL_FROM)){
            $from = $conf->global->MAILING_EMAIL_FROM;
        }

        //Todo Repasser sur les trads
        if(empty($sendTo) || empty($from)){
            setEventMessage("Destinataire ou expéditeur manquant !",'errors');
        }
        else {
            $mailFile = new CMailFile($subject, $sendTo, $from, $message, $formmail->get_attached_files()["paths"], $formmail->get_attached_files()["mimes"], $formmail->get_attached_files()["names"], "", "", "", 1);
            $res = $mailFile->sendfile();
            if ($res > 0) {
                setEventMessage("Le ticket a bien été envoyé !");
                unset($_POST["sendmail"]);
            } else {
                setEventMessage($mailFile->error, 'errors');
                setEventMessage($mailFile->errors, 'errors');
            }
        }


    }
    else{
        setEventMessage("Des champs requis sont manquants pour l'envoi du ticket.",'errors');
    }

}

print $formmail->get_form('addfile', 'removefile');
//print '<script type="text/javascript">
//       $("tbody").children().eq(5).remove();
//       $("tbody").children().eq(3).after('.$subjectHTML.');
//       </script>';

//
//print '<table>';
//print '<tbody>';
//
//print '<tr>';
//print '<td class="titlefieldcreate"><span class="fieldrequired">Type de demande</span></td>';
//print  '<td>';
//print '<select class="flat" name="typeOfTicket">';
//for($i=0;$i<count($typeOfTicket);$i++){
//    print '<option value="'.$i.'">'.$langs->trans($typeOfTicket[$i]).'</option>';
//}
//print '</select>';
//print '</td>';
//print '</tr>';
//
//print '<tr>';
//print '<td class="titlefieldcreate"><span class="fieldrequired">Sévérité</span></td>';
//print  '<td>';
//print '<select class="flat" name="ticketSeverity">';
//for($i=0;$i<count($typeOfSeverity);$i++){
//    print '<option value="'.$i.'">'.$langs->trans($typeOfSeverity[$i]).'</option>';
//}
//print '</select>';
//print '</td>';
//print '</tr>';
//
//
//print '<tr>';
//print '<td class="titlefieldcreate"><span class="fieldrequired">Sujet</span></td>';
//print  '<td>';
//print '<input class="flat" type="text" name="subject">';
//print '</td>';
//print '</tr>';
//
//
//print '<tr>';
//print '<td class="titlefieldcreate"><span class="fieldrequired">Message</span></td>';
//print  '<td>';
//print '<textarea name="message" style="margin: 5px 0px 0px; width: 500px; height: 154px;" class="flat"></textarea>';
//print '</td>';
//print '</tr>';
//
//
//print '<tr>';
//print '<td class="titlefieldcreate"><span>Joindre un fichier</span></td>';
//print  '<td>';
//print '<input type="file" class="flat" id="addedfile" name="addedfile" value="Envoyer fichier">';
//print '</td>';
//print '</tr>';


//
//
//print '<tr>';
//print '</tr>';
//print '</tbody>';
//print '</table>';
//print '</form>';



// End of page
print '<script type="text/javascript"> 
        $("'.$ticketParams.'").insertBefore($("#mailform tbody:first"))
         </script>';

llxFooter();
$db->close();
